#
# spec file for package python-kmatch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-kmatch
Version:        0.5.0
Release:        2.7
Summary:        A language for matching/validating/filtering Python dictionaries
License:        MIT
URL:            https://github.com/ambitioninc/kmatch
Source:         https://files.pythonhosted.org/packages/source/k/kmatch/kmatch-%{version}.tar.gz
# https://github.com/ambitioninc/kmatch/issues/42
Patch0:         python-kmatch-no-mock.patch
Patch1:         fix-assertion-methods.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The kmatch library provides a language for matching Python
dictionaries. Patterns are specified as lists of filters combined
with logical operators.

%prep
%autosetup -p1 -n kmatch-%{version}
sed -i '/nose/d' setup.py
dos2unix README.rst LICENSE
chmod a-x README.rst LICENSE
rm -r *.egg-info

%build
mv kmatch/tests/ .tests
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
mv .tests tests
%pytest tests/*_tests.py

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/kmatch
%{python_sitelib}/kmatch-%{version}.dist-info

%changelog
* Wed Jan 24 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- Stop using greedy globs in %%files.
- Add patch fix-assertion-methods.patch:
  * Use non-deprecated assertion methods.
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.0:
  * Add support for python 3.9
  * Drop support for python 3.5, 3.6
* Tue Aug  2 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on mock.
* Wed Mar 23 2022 pgajdos@suse.com
- version update to 0.4.0
  * no upstream changelog
- added patches
  fix https://github.com/ambitioninc/kmatch/issues/42
  + python-kmatch-no-mock.patch
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Re-activate test suite replacing nose with pytest
- Remove tests from runtime package
- dos2unix several files
- Tidy spec
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.0:
  * no upstream changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Update descriptions.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 0.2.1
  * Use property and setter for suppress exceptions
- Update to 0.2.0
  * Handle data type mismatch comparisons and return False
- Spec file cleanups
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to 0.1.7
  * See changelog at https://github.com/ambitioninc/kmatch/blob/develop/docs/release_notes.rst#v017
* Wed Jul 30 2014 toddrme2178@gmail.com
- Initial version
